@@ -33,7 +33,7 @@ class plot:
 
     #LOG,INFO,WARN,ERROR,
     def intro():
-        print("这是TechYoung课程的机器学习辅助工具包")
+        print("这是地球号旗下数据分析绘图包")
         return True
 
     """
@@ -60,7 +60,9 @@ class plot:
         plt.axvline(x=column_mean + 2*column_std, color="r", linewidth=1)
         datetime_str = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S%f')
         file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
-        plt.savefig(file_name + ".png", dpi=100)
+        file_name = file_name + ".png"
+        print(file_name)
+        plt.savefig(file_name, dpi=100)
         return True
     def normal_distribution(mean, sigma):
         x = np.linspace(mean - 6*sigma, mean + 6*sigma, 100)
@@ -112,6 +114,7 @@ class plot:
             plt.plot(x, y, color = "black")
         datetime_str = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S%f')
         file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
+        print(file_name)
         plt.savefig(file_name + ".png", dpi=100)
         return True
 
@@ -173,6 +176,7 @@ class plot:
             plt.plot(x, y, color = "black")
         datetime_str = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S%f')
         file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
+        print(file_name)
         plt.savefig(file_name + ".png", dpi=100)
         return True
 
